@@ -12,6 +12,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+"""
+.. Explicitly document private _AggregationFactory
+.. autoclass:: _AggregationFactory
+"""
+
 from abc import ABC, abstractmethod
 from bisect import bisect_left
 from dataclasses import replace
@@ -22,18 +27,20 @@ from typing import Generic, List, Optional, Sequence, TypeVar
 
 from opentelemetry._metrics.instrument import (
     Asynchronous,
+    Counter,
+    Histogram,
     Instrument,
+    ObservableCounter,
+    ObservableGauge,
+    ObservableUpDownCounter,
     Synchronous,
+    UpDownCounter,
     _Monotonic,
 )
 from opentelemetry.sdk._metrics.measurement import Measurement
-from opentelemetry.sdk._metrics.point import (
-    AggregationTemporality,
-    Gauge,
-    Histogram,
-    PointT,
-    Sum,
-)
+from opentelemetry.sdk._metrics.point import AggregationTemporality, Gauge
+from opentelemetry.sdk._metrics.point import Histogram as HistogramPoint
+from opentelemetry.sdk._metrics.point import PointT, Sum
 from opentelemetry.util._time import _time_ns
 
 _PointVarT = TypeVar("_PointVarT", bound=PointT)
@@ -54,6 +61,74 @@ class _Aggregation(ABC, Generic[_PointVarT]):
         pass
 
 
+class _DropAggregation(_Aggregation):
+    def aggregate(self, measurement: Measurement) -> None:
+        pass
+
+    def collect(self) -> Optional[_PointVarT]:
+        pass
+
+
+class _AggregationFactory(ABC):
+    @abstractmethod
+    def _create_aggregation(self, instrument: Instrument) -> _Aggregation:
+        """Creates an aggregation"""
+
+
+class DefaultAggregation(_AggregationFactory):
+    """
+    The default aggregation to be used in a `View`.
+
+    This aggregation will create an actual aggregation depending on the
+    instrument type, as specified next:
+
+    ========================= ====================================
+    Instrument                Aggregation
+    ========================= ====================================
+    `Counter`                 `SumAggregation`
+    `UpDownCounter`           `SumAggregation`
+    `ObservableCounter`       `SumAggregation`
+    `ObservableUpDownCounter` `SumAggregation`
+    `Histogram`               `ExplicitBucketHistogramAggregation`
+    `ObservableGauge`         `LastValueAggregation`
+    ========================= ====================================
+    """
+
+    def _create_aggregation(self, instrument: Instrument) -> _Aggregation:
+
+        # pylint: disable=too-many-return-statements
+        if isinstance(instrument, Counter):
+            return _SumAggregation(
+                instrument_is_monotonic=True,
+                instrument_temporality=AggregationTemporality.DELTA,
+            )
+        if isinstance(instrument, UpDownCounter):
+            return _SumAggregation(
+                instrument_is_monotonic=False,
+                instrument_temporality=AggregationTemporality.DELTA,
+            )
+
+        if isinstance(instrument, ObservableCounter):
+            return _SumAggregation(
+                instrument_is_monotonic=True,
+                instrument_temporality=AggregationTemporality.CUMULATIVE,
+            )
+
+        if isinstance(instrument, ObservableUpDownCounter):
+            return _SumAggregation(
+                instrument_is_monotonic=False,
+                instrument_temporality=AggregationTemporality.CUMULATIVE,
+            )
+
+        if isinstance(instrument, Histogram):
+            return _ExplicitBucketHistogramAggregation()
+
+        if isinstance(instrument, ObservableGauge):
+            return _LastValueAggregation()
+
+        raise Exception(f"Invalid instrument type {type(instrument)} found")
+
+
 class _SumAggregation(_Aggregation[Sum]):
     def __init__(
         self,
@@ -141,7 +216,7 @@ class _LastValueAggregation(_Aggregation[Gauge]):
         )
 
 
-class _ExplicitBucketHistogramAggregation(_Aggregation[Histogram]):
+class _ExplicitBucketHistogramAggregation(_Aggregation[HistogramPoint]):
     def __init__(
         self,
         boundaries: Sequence[float] = (
@@ -182,7 +257,7 @@ class _ExplicitBucketHistogramAggregation(_Aggregation[Histogram]):
 
         self._bucket_counts[bisect_left(self._boundaries, value)] += 1
 
-    def collect(self) -> Histogram:
+    def collect(self) -> HistogramPoint:
         """
         Atomically return a point for the current value of the metric.
         """
@@ -191,17 +266,25 @@ class _ExplicitBucketHistogramAggregation(_Aggregation[Histogram]):
         with self._lock:
             value = self._bucket_counts
             start_time_unix_nano = self._start_time_unix_nano
+            histogram_sum = self._sum
+            histogram_max = self._max
+            histogram_min = self._min
 
             self._bucket_counts = self._get_empty_bucket_counts()
             self._start_time_unix_nano = now + 1
+            self._sum = 0
+            self._min = inf
+            self._max = -inf
 
-        return Histogram(
-            start_time_unix_nano=start_time_unix_nano,
-            time_unix_nano=now,
+        return HistogramPoint(
+            aggregation_temporality=AggregationTemporality.DELTA,
             bucket_counts=tuple(value),
             explicit_bounds=self._boundaries,
-            aggregation_temporality=AggregationTemporality.DELTA,
-            sum=self._sum,
+            max=histogram_max,
+            min=histogram_min,
+            start_time_unix_nano=start_time_unix_nano,
+            sum=histogram_sum,
+            time_unix_nano=now,
         )
 
 
@@ -226,8 +309,10 @@ def _convert_aggregation_temporality(
     if current_point_type is Gauge:
         return current_point
 
-    if previous_point is not None and type(previous_point) is not type(
-        current_point
+    if (
+        previous_point is not None
+        and current_point is not None
+        and type(previous_point) is not type(current_point)
     ):
         _logger.warning(
             "convert_aggregation_temporality called with mismatched "
@@ -280,7 +365,7 @@ def _convert_aggregation_temporality(
             is_monotonic=is_monotonic,
         )
 
-    if current_point_type is Histogram:
+    if current_point_type is HistogramPoint:
         if previous_point is None:
             return replace(
                 current_point, aggregation_temporality=aggregation_temporality
@@ -295,9 +380,15 @@ def _convert_aggregation_temporality(
         if current_point.aggregation_temporality is aggregation_temporality:
             return current_point
 
+        max_ = current_point.max
+        min_ = current_point.min
+
         if aggregation_temporality is AggregationTemporality.CUMULATIVE:
             start_time_unix_nano = previous_point.start_time_unix_nano
             sum_ = current_point.sum + previous_point.sum
+            # Only update min/max on delta -> cumulative
+            max_ = max(current_point.max, previous_point.max)
+            min_ = min(current_point.min, previous_point.min)
             bucket_counts = [
                 curr_count + prev_count
                 for curr_count, prev_count in zip(
@@ -314,23 +405,19 @@ def _convert_aggregation_temporality(
                 )
             ]
 
-        return Histogram(
-            start_time_unix_nano=start_time_unix_nano,
-            time_unix_nano=current_point.time_unix_nano,
+        return HistogramPoint(
+            aggregation_temporality=aggregation_temporality,
             bucket_counts=bucket_counts,
             explicit_bounds=current_point.explicit_bounds,
+            max=max_,
+            min=min_,
+            start_time_unix_nano=start_time_unix_nano,
             sum=sum_,
-            aggregation_temporality=aggregation_temporality,
+            time_unix_nano=current_point.time_unix_nano,
         )
     return None
 
 
-class _AggregationFactory(ABC):
-    @abstractmethod
-    def _create_aggregation(self, instrument: Instrument) -> _Aggregation:
-        """Creates an aggregation"""
-
-
 class ExplicitBucketHistogramAggregation(_AggregationFactory):
     def __init__(
         self,
@@ -376,3 +463,10 @@ class SumAggregation(_AggregationFactory):
 class LastValueAggregation(_AggregationFactory):
     def _create_aggregation(self, instrument: Instrument) -> _Aggregation:
         return _LastValueAggregation()
+
+
+class DropAggregation(_AggregationFactory):
+    """Using this aggregation will make all measurements be ignored."""
+
+    def _create_aggregation(self, instrument: Instrument) -> _Aggregation:
+        return _DropAggregation()
