@@ -15,8 +15,7 @@
 # pylint: disable=too-many-ancestors
 
 import logging
-from abc import ABC, abstractmethod
-from typing import Callable, Dict, Generator, Iterable, Union
+from typing import Dict, Generator, Iterable, Optional, Union
 
 from opentelemetry._metrics.instrument import CallbackT
 from opentelemetry._metrics.instrument import Counter as APICounter
@@ -31,29 +30,14 @@ from opentelemetry._metrics.instrument import (
     ObservableUpDownCounter as APIObservableUpDownCounter,
 )
 from opentelemetry._metrics.instrument import UpDownCounter as APIUpDownCounter
-from opentelemetry._metrics.measurement import Measurement as APIMeasurement
-from opentelemetry.sdk._metrics.aggregation import (
-    _Aggregation,
-    _ExplicitBucketHistogramAggregation,
-    _LastValueAggregation,
-    _SumAggregation,
-)
 from opentelemetry.sdk._metrics.measurement import Measurement
 from opentelemetry.sdk._metrics.measurement_consumer import MeasurementConsumer
-from opentelemetry.sdk._metrics.point import AggregationTemporality
 from opentelemetry.sdk.util.instrumentation import InstrumentationInfo
 
 _logger = logging.getLogger(__name__)
 
 
-class _Instrument(ABC):
-    @property
-    @abstractmethod
-    def _default_aggregation(self) -> _Aggregation:
-        pass
-
-
-class _Synchronous(_Instrument):
+class _Synchronous:
     def __init__(
         self,
         name: str,
@@ -70,13 +54,13 @@ class _Synchronous(_Instrument):
         super().__init__(name, unit=unit, description=description)
 
 
-class _Asynchronous(_Instrument):
+class _Asynchronous:
     def __init__(
         self,
         name: str,
         instrumentation_info: InstrumentationInfo,
         measurement_consumer: MeasurementConsumer,
-        callback: CallbackT,
+        callbacks: Optional[Iterable[CallbackT]] = None,
         unit: str = "",
         description: str = "",
     ):
@@ -85,36 +69,37 @@ class _Asynchronous(_Instrument):
         self.description = description
         self.instrumentation_info = instrumentation_info
         self._measurement_consumer = measurement_consumer
-        super().__init__(name, callback, unit=unit, description=description)
+        super().__init__(name, callbacks, unit=unit, description=description)
 
-        self._callback: Callable[[], Iterable[APIMeasurement]]
+        self._callbacks = []
 
-        if isinstance(callback, Generator):
+        if callbacks is not None:
 
-            def inner() -> Iterable[Measurement]:
-                return next(callback)
+            for callback in callbacks:
 
-            self._callback = inner
-        else:
-            self._callback = callback
+                if isinstance(callback, Generator):
+
+                    def inner(callback=callback) -> Iterable[Measurement]:
+                        return next(callback)
+
+                    self._callbacks.append(inner)
+                else:
+                    self._callbacks.append(callback)
 
     def callback(self) -> Iterable[Measurement]:
-        for api_measurement in self._callback():
-            yield Measurement(
-                api_measurement.value,
-                instrument=self,
-                attributes=api_measurement.attributes,
-            )
+        for callback in self._callbacks:
+            try:
+                for api_measurement in callback():
+                    yield Measurement(
+                        api_measurement.value,
+                        instrument=self,
+                        attributes=api_measurement.attributes,
+                    )
+            except StopIteration:
+                pass
 
 
 class Counter(_Synchronous, APICounter):
-    @property
-    def _default_aggregation(self) -> _Aggregation:
-        return _SumAggregation(
-            instrument_is_monotonic=True,
-            instrument_temporality=AggregationTemporality.DELTA,
-        )
-
     def add(
         self, amount: Union[int, float], attributes: Dict[str, str] = None
     ):
@@ -129,13 +114,6 @@ class Counter(_Synchronous, APICounter):
 
 
 class UpDownCounter(_Synchronous, APIUpDownCounter):
-    @property
-    def _default_aggregation(self) -> _Aggregation:
-        return _SumAggregation(
-            instrument_is_monotonic=False,
-            instrument_temporality=AggregationTemporality.DELTA,
-        )
-
     def add(
         self, amount: Union[int, float], attributes: Dict[str, str] = None
     ):
@@ -145,28 +123,14 @@ class UpDownCounter(_Synchronous, APIUpDownCounter):
 
 
 class ObservableCounter(_Asynchronous, APIObservableCounter):
-    @property
-    def _default_aggregation(self) -> _Aggregation:
-        return _SumAggregation(
-            instrument_is_monotonic=True,
-            instrument_temporality=AggregationTemporality.CUMULATIVE,
-        )
+    pass
 
 
 class ObservableUpDownCounter(_Asynchronous, APIObservableUpDownCounter):
-    @property
-    def _default_aggregation(self) -> _Aggregation:
-        return _SumAggregation(
-            instrument_is_monotonic=False,
-            instrument_temporality=AggregationTemporality.CUMULATIVE,
-        )
+    pass
 
 
 class Histogram(_Synchronous, APIHistogram):
-    @property
-    def _default_aggregation(self) -> _Aggregation:
-        return _ExplicitBucketHistogramAggregation()
-
     def record(
         self, amount: Union[int, float], attributes: Dict[str, str] = None
     ):
@@ -182,6 +146,4 @@ class Histogram(_Synchronous, APIHistogram):
 
 
 class ObservableGauge(_Asynchronous, APIObservableGauge):
-    @property
-    def _default_aggregation(self) -> _Aggregation:
-        return _LastValueAggregation()
+    pass
