@@ -58,7 +58,7 @@ class TestUpDownCounter(TestCase):
 TEST_ATTRIBUTES = {"foo": "bar"}
 
 
-def callable_callback():
+def callable_callback_0():
     return [
         APIMeasurement(1, attributes=TEST_ATTRIBUTES),
         APIMeasurement(2, attributes=TEST_ATTRIBUTES),
@@ -66,7 +66,15 @@ def callable_callback():
     ]
 
 
-def generator_callback():
+def callable_callback_1():
+    return [
+        APIMeasurement(4, attributes=TEST_ATTRIBUTES),
+        APIMeasurement(5, attributes=TEST_ATTRIBUTES),
+        APIMeasurement(6, attributes=TEST_ATTRIBUTES),
+    ]
+
+
+def generator_callback_0():
     yield [
         APIMeasurement(1, attributes=TEST_ATTRIBUTES),
         APIMeasurement(2, attributes=TEST_ATTRIBUTES),
@@ -74,10 +82,18 @@ def generator_callback():
     ]
 
 
+def generator_callback_1():
+    yield [
+        APIMeasurement(4, attributes=TEST_ATTRIBUTES),
+        APIMeasurement(5, attributes=TEST_ATTRIBUTES),
+        APIMeasurement(6, attributes=TEST_ATTRIBUTES),
+    ]
+
+
 class TestObservableGauge(TestCase):
-    def test_callable_callback(self):
+    def test_callable_callback_0(self):
         observable_gauge = ObservableGauge(
-            "name", Mock(), Mock(), callable_callback
+            "name", Mock(), Mock(), [callable_callback_0]
         )
 
         self.assertEqual(
@@ -95,9 +111,9 @@ class TestObservableGauge(TestCase):
             ],
         )
 
-    def test_generator_callback(self):
+    def test_callable_multiple_callable_callback(self):
         observable_gauge = ObservableGauge(
-            "name", Mock(), Mock(), generator_callback()
+            "name", Mock(), Mock(), [callable_callback_0, callable_callback_1]
         )
 
         self.assertEqual(
@@ -112,14 +128,76 @@ class TestObservableGauge(TestCase):
                 Measurement(
                     3, instrument=observable_gauge, attributes=TEST_ATTRIBUTES
                 ),
+                Measurement(
+                    4, instrument=observable_gauge, attributes=TEST_ATTRIBUTES
+                ),
+                Measurement(
+                    5, instrument=observable_gauge, attributes=TEST_ATTRIBUTES
+                ),
+                Measurement(
+                    6, instrument=observable_gauge, attributes=TEST_ATTRIBUTES
+                ),
+            ],
+        )
+
+    def test_generator_callback_0(self):
+        observable_gauge = ObservableGauge(
+            "name", Mock(), Mock(), [generator_callback_0()]
+        )
+
+        self.assertEqual(
+            list(observable_gauge.callback()),
+            [
+                Measurement(
+                    1, instrument=observable_gauge, attributes=TEST_ATTRIBUTES
+                ),
+                Measurement(
+                    2, instrument=observable_gauge, attributes=TEST_ATTRIBUTES
+                ),
+                Measurement(
+                    3, instrument=observable_gauge, attributes=TEST_ATTRIBUTES
+                ),
+            ],
+        )
+
+    def test_generator_multiple_generator_callback(self):
+        self.maxDiff = None
+        observable_gauge = ObservableGauge(
+            "name",
+            Mock(),
+            Mock(),
+            callbacks=[generator_callback_0(), generator_callback_1()],
+        )
+
+        self.assertEqual(
+            list(observable_gauge.callback()),
+            [
+                Measurement(
+                    1, instrument=observable_gauge, attributes=TEST_ATTRIBUTES
+                ),
+                Measurement(
+                    2, instrument=observable_gauge, attributes=TEST_ATTRIBUTES
+                ),
+                Measurement(
+                    3, instrument=observable_gauge, attributes=TEST_ATTRIBUTES
+                ),
+                Measurement(
+                    4, instrument=observable_gauge, attributes=TEST_ATTRIBUTES
+                ),
+                Measurement(
+                    5, instrument=observable_gauge, attributes=TEST_ATTRIBUTES
+                ),
+                Measurement(
+                    6, instrument=observable_gauge, attributes=TEST_ATTRIBUTES
+                ),
             ],
         )
 
 
 class TestObservableCounter(TestCase):
-    def test_callable_callback(self):
+    def test_callable_callback_0(self):
         observable_counter = ObservableCounter(
-            "name", Mock(), Mock(), callable_callback
+            "name", Mock(), Mock(), [callable_callback_0]
         )
 
         self.assertEqual(
@@ -143,9 +221,9 @@ class TestObservableCounter(TestCase):
             ],
         )
 
-    def test_generator_callback(self):
+    def test_generator_callback_0(self):
         observable_counter = ObservableCounter(
-            "name", Mock(), Mock(), generator_callback()
+            "name", Mock(), Mock(), [generator_callback_0()]
         )
 
         self.assertEqual(
@@ -171,9 +249,9 @@ class TestObservableCounter(TestCase):
 
 
 class TestObservableUpDownCounter(TestCase):
-    def test_callable_callback(self):
+    def test_callable_callback_0(self):
         observable_up_down_counter = ObservableUpDownCounter(
-            "name", Mock(), Mock(), callable_callback
+            "name", Mock(), Mock(), [callable_callback_0]
         )
 
         self.assertEqual(
@@ -197,9 +275,9 @@ class TestObservableUpDownCounter(TestCase):
             ],
         )
 
-    def test_generator_callback(self):
+    def test_generator_callback_0(self):
         observable_up_down_counter = ObservableUpDownCounter(
-            "name", Mock(), Mock(), generator_callback()
+            "name", Mock(), Mock(), [generator_callback_0()]
         )
 
         self.assertEqual(
