@@ -19,6 +19,7 @@ from unittest.mock import MagicMock, Mock, patch
 
 from opentelemetry._metrics import NoOpMeter
 from opentelemetry.sdk._metrics import Meter, MeterProvider
+from opentelemetry.sdk._metrics.export import PeriodicExportingMetricReader
 from opentelemetry.sdk._metrics.instrument import (
     Counter,
     Histogram,
@@ -45,6 +46,25 @@ class DummyMetricReader(MetricReader):
 
 
 class TestMeterProvider(ConcurrencyTestBase):
+    def tearDown(self):
+
+        MeterProvider._all_metric_readers = set()
+
+    def test_register_metric_readers(self):
+
+        metric_reader_0 = PeriodicExportingMetricReader(Mock())
+        metric_reader_1 = PeriodicExportingMetricReader(Mock())
+
+        try:
+            MeterProvider(metric_readers=(metric_reader_0,))
+            MeterProvider(metric_readers=(metric_reader_1,))
+        except Exception as error:
+            self.fail(f"Unexpected exception {error} raised")
+
+        with self.assertRaises(Exception):
+            MeterProvider(metric_readers=(metric_reader_0,))
+            MeterProvider(metric_readers=(metric_reader_0,))
+
     def test_resource(self):
         """
         `MeterProvider` provides a way to allow a `Resource` to be specified.
@@ -131,33 +151,45 @@ class TestMeterProvider(ConcurrencyTestBase):
 
         mock_metric_reader_0 = MagicMock(
             **{
-                "shutdown.return_value": False,
-                "__str__.return_value": "mock_metric_reader_0",
+                "shutdown.side_effect": ZeroDivisionError(),
+            }
+        )
+        mock_metric_reader_1 = MagicMock(
+            **{
+                "shutdown.side_effect": AssertionError(),
             }
         )
-        mock_metric_reader_1 = Mock(**{"shutdown.return_value": True})
 
         meter_provider = MeterProvider(
             metric_readers=[mock_metric_reader_0, mock_metric_reader_1]
         )
 
-        with self.assertLogs(level=WARNING) as log:
-            self.assertFalse(meter_provider.shutdown())
-            self.assertEqual(
-                log.records[0].getMessage(),
-                "MetricReader mock_metric_reader_0 failed to shutdown",
-            )
+        with self.assertRaises(Exception) as error:
+            meter_provider.shutdown()
+
+        error = error.exception
+
+        self.assertEqual(
+            str(error),
+            (
+                "MeterProvider.shutdown failed because the following "
+                "metric readers failed during shutdown:\n"
+                "MagicMock: ZeroDivisionError()\n"
+                "MagicMock: AssertionError()"
+            ),
+        )
+
         mock_metric_reader_0.shutdown.assert_called_once()
         mock_metric_reader_1.shutdown.assert_called_once()
 
-        mock_metric_reader_0 = Mock(**{"shutdown.return_value": True})
-        mock_metric_reader_1 = Mock(**{"shutdown.return_value": True})
+        mock_metric_reader_0 = Mock()
+        mock_metric_reader_1 = Mock()
 
         meter_provider = MeterProvider(
             metric_readers=[mock_metric_reader_0, mock_metric_reader_1]
         )
 
-        self.assertTrue(meter_provider.shutdown())
+        self.assertIsNone(meter_provider.shutdown())
         mock_metric_reader_0.shutdown.assert_called_once()
         mock_metric_reader_1.shutdown.assert_called_once()
 
@@ -190,7 +222,13 @@ class TestMeterProvider(ConcurrencyTestBase):
     def test_measurement_collect_callback(
         self, mock_sync_measurement_consumer
     ):
-        metric_readers = [DummyMetricReader()] * 5
+        metric_readers = [
+            DummyMetricReader(),
+            DummyMetricReader(),
+            DummyMetricReader(),
+            DummyMetricReader(),
+            DummyMetricReader(),
+        ]
         sync_consumer_instance = mock_sync_measurement_consumer()
         sync_consumer_instance.collect = MockFunc()
         MeterProvider(metric_readers=metric_readers)
@@ -217,17 +255,17 @@ class TestMeterProvider(ConcurrencyTestBase):
 
         meter_provider._measurement_consumer.register_asynchronous_instrument.assert_called_with(
             meter_provider.get_meter("name").create_observable_counter(
-                "name", Mock()
+                "name0", callbacks=[Mock()]
             )
         )
         meter_provider._measurement_consumer.register_asynchronous_instrument.assert_called_with(
             meter_provider.get_meter("name").create_observable_up_down_counter(
-                "name", Mock()
+                "name1", callbacks=[Mock()]
             )
         )
         meter_provider._measurement_consumer.register_asynchronous_instrument.assert_called_with(
             meter_provider.get_meter("name").create_observable_gauge(
-                "name", Mock()
+                "name2", callbacks=[Mock()]
             )
         )
 
@@ -272,6 +310,43 @@ class TestMeter(TestCase):
     def setUp(self):
         self.meter = Meter(Mock(), Mock())
 
+    def test_repeated_instrument_names(self):
+        try:
+            self.meter.create_counter("counter")
+            self.meter.create_up_down_counter("up_down_counter")
+            self.meter.create_observable_counter(
+                "observable_counter", callbacks=[Mock()]
+            )
+            self.meter.create_histogram("histogram")
+            self.meter.create_observable_gauge(
+                "observable_gauge", callbacks=[Mock()]
+            )
+            self.meter.create_observable_up_down_counter(
+                "observable_up_down_counter", callbacks=[Mock()]
+            )
+        except Exception as error:
+            self.fail(f"Unexpected exception raised {error}")
+
+        for instrument_name in [
+            "counter",
+            "up_down_counter",
+            "histogram",
+        ]:
+            with self.assertLogs(level=WARNING):
+                getattr(self.meter, f"create_{instrument_name}")(
+                    instrument_name
+                )
+
+        for instrument_name in [
+            "observable_counter",
+            "observable_gauge",
+            "observable_up_down_counter",
+        ]:
+            with self.assertLogs(level=WARNING):
+                getattr(self.meter, f"create_{instrument_name}")(
+                    instrument_name, callbacks=[Mock()]
+                )
+
     def test_create_counter(self):
         counter = self.meter.create_counter(
             "name", unit="unit", description="description"
@@ -290,7 +365,7 @@ class TestMeter(TestCase):
 
     def test_create_observable_counter(self):
         observable_counter = self.meter.create_observable_counter(
-            "name", Mock(), unit="unit", description="description"
+            "name", callbacks=[Mock()], unit="unit", description="description"
         )
 
         self.assertIsInstance(observable_counter, ObservableCounter)
@@ -306,7 +381,7 @@ class TestMeter(TestCase):
 
     def test_create_observable_gauge(self):
         observable_gauge = self.meter.create_observable_gauge(
-            "name", Mock(), unit="unit", description="description"
+            "name", callbacks=[Mock()], unit="unit", description="description"
         )
 
         self.assertIsInstance(observable_gauge, ObservableGauge)
@@ -315,7 +390,10 @@ class TestMeter(TestCase):
     def test_create_observable_up_down_counter(self):
         observable_up_down_counter = (
             self.meter.create_observable_up_down_counter(
-                "name", Mock(), unit="unit", description="description"
+                "name",
+                callbacks=[Mock()],
+                unit="unit",
+                description="description",
             )
         )
         self.assertIsInstance(
